Composes — bodhi 3.10.1 documentation

# Composes

`cornice_sphinx` does not yet have the ability to render documentation for the `/composes/` API, so we will include docblock documentation for that service here instead.

class `bodhi.server.services.composes.` `Composes`(request, context=None)

  Defines resources for interacting with Compose objects.

  Operations acting on the collection are served at `/composes/` and operations acting on a single compose are served at `/composes/<release_name>/<request>`.